#!/usr/bin/python3
#
# -*- coding: utf-8 -*-
#
# This hook script adds permission to use given SAML SPs to users
#
# Copyright 2019-2022 Univention GmbH
#
# http://www.univention.de/
#
# All rights reserved.
#
# The source code of this program is made available
# under the terms of the GNU Affero General Public License version 3
# (GNU AGPL V3) as published by the Free Software Foundation.
#
# Binary versions of this program provided by Univention to you as
# well as other copyrighted, protected or trademarked materials like
# Logos, graphics, fonts, specific documentations and configurations,
# cryptographic keys etc. are subject to a license agreement between
# you and Univention and not subject to the GNU AGPL V3.
#
# In the case you use this program under the terms of the GNU AGPL V3,
# the program is provided in the hope that it will be useful,
# but WITHOUT ANY WARRANTY; without even the implied warranty of
# MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE. See the
# GNU Affero General Public License for more details.
#
# You should have received a copy of the GNU Affero General Public
# License with the Debian GNU/Linux or Univention distribution in file
# /usr/share/common-licenses/AGPL-3; if not, see
# <http://www.gnu.org/licenses/>.

from __future__ import absolute_import

from ucsschool.importer.utils.user_pyhook import UserPyHook

from univention.config_registry import ConfigRegistry


class AddSamlSp(UserPyHook):
    name = "Add_Saml_SPs"

    ucr = ConfigRegistry()
    ucr.load()
    ldap_base = ucr.get("ldap/base")
    domain_name = ucr.get("domainname")

    saml_SPs = ["https://webmail.{}/appsuite/".format(domain_name)]

    priority = {
        "pre_create": 100,
        "post_create": None,
        "pre_modify": 100,
        "post_modify": None,
        "pre_move": None,
        "post_move": None,
        "pre_remove": None,
        "post_remove": None,
    }

    def add_SPs(self, user):
        user.udm_properties["serviceprovider"] = []
        for sp in self.saml_SPs:
            user.udm_properties["serviceprovider"].append(
                "SAMLServiceProviderIdentifier={},cn=saml-serviceprovider,cn=univention,{}".format(
                    sp, self.ldap_base
                )
            )
        self.logger.info(
            "{}: Added following SPs to user {} {}.".format(
                self.name, user, user.udm_properties["serviceprovider"]
            )
        )

    def pre_create(self, user):
        self.logger.info("Running %s pre_create hook for %s.", self.name, user)
        self.add_SPs(user)

    def pre_modify(self, user):
        self.logger.info("Running %s pre_modify hook for %s.", self.name, user)
        self.add_SPs(user)


# vim: set ts=4 sw=4 et
